# coding: utf-8

"""
    Nomad Pilot

    This is the API descriptor for the Nomad Pilot API, responsible for shipping and logistics processing. Developed by `Samarkand Global <https://samarkand.global>`_ in partnership with `SF Express <https://www.sf- express.com/cn/sc/>`_, `eSinotrans <http://www.esinotrans.com/haitao.html>`_. Read the documentation online at `Nomad API Suite <https://api.samarkand.io/>`_ and Check out the detailed `changelog <https://gitlab.com/samarkand-nomad/nomad_readme/-/raw/master/history/nomad_pilot.md>`_. - Install for node with ``npm install nomad_pilot_cli`` - Install for python with ``pip install nomad-pilot-cli``  # noqa: E501

    The version of the OpenAPI document: 1.29.1
    Contact: paul@samarkand.global
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import nomad_pilot_cli
from nomad_pilot_cli.models.api_response_connector_response import ApiResponseConnectorResponse  # noqa: E501
from nomad_pilot_cli.rest import ApiException

class TestApiResponseConnectorResponse(unittest.TestCase):
    """ApiResponseConnectorResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ApiResponseConnectorResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = nomad_pilot_cli.models.api_response_connector_response.ApiResponseConnectorResponse()  # noqa: E501
        if include_optional :
            return ApiResponseConnectorResponse(
                input = '{"product_id": 12121}', 
                mapping_name = 'GetProductOp', 
                api = [
                    '0'
                    ], 
                http_request_raw_data = '-', 
                code = 56, 
                response = '0', 
                response_en = '0', 
                platform = 'youzan', 
                request_count = 1, 
                response_time = 1000
            )
        else :
            return ApiResponseConnectorResponse(
        )

    def testApiResponseConnectorResponse(self):
        """Test ApiResponseConnectorResponse"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
