# coding: utf-8

# flake8: noqa

"""
    Nomad Pilot

    This is the API descriptor for the Nomad Pilot API, responsible for shipping and logistics processing. Developed by `Samarkand Global <https://samarkand.global>`_ in partnership with `SF Express <https://www.sf- express.com/cn/sc/>`_, `eSinotrans <http://www.esinotrans.com/haitao.html>`_. Read the documentation online at `Nomad API Suite <https://api.samarkand.io/>`_ and Check out the detailed `changelog <https://gitlab.com/samarkand-nomad/nomad_readme/-/raw/master/history/nomad_pilot.md>`_. - Install for node with ``npm install nomad_pilot_cli`` - Install for python with ``pip install nomad-pilot-cli``  # noqa: E501

    The version of the OpenAPI document: 1.29.1
    Contact: paul@samarkand.global
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "1.29.1"

# import apis into sdk package
from nomad_pilot_cli.api.freight_forward_api import FreightForwardApi
from nomad_pilot_cli.api.quick_ship_api import QuickShipApi
from nomad_pilot_cli.api.ship_api import ShipApi
from nomad_pilot_cli.api.ship_confirm_api import ShipConfirmApi

# import ApiClient
from nomad_pilot_cli.api_client import ApiClient
from nomad_pilot_cli.configuration import Configuration
from nomad_pilot_cli.exceptions import OpenApiException
from nomad_pilot_cli.exceptions import ApiTypeError
from nomad_pilot_cli.exceptions import ApiValueError
from nomad_pilot_cli.exceptions import ApiKeyError
from nomad_pilot_cli.exceptions import ApiException
# import models into sdk package
from nomad_pilot_cli.models.address import Address
from nomad_pilot_cli.models.address_required import AddressRequired
from nomad_pilot_cli.models.address_ship import AddressShip
from nomad_pilot_cli.models.api_response import ApiResponse
from nomad_pilot_cli.models.api_response_connector_response import ApiResponseConnectorResponse
from nomad_pilot_cli.models.api_response_data import ApiResponseData
from nomad_pilot_cli.models.api_response_general import ApiResponseGeneral
from nomad_pilot_cli.models.dimension import Dimension
from nomad_pilot_cli.models.goldjet import Goldjet
from nomad_pilot_cli.models.pack import Pack
from nomad_pilot_cli.models.pack_based import PackBased
from nomad_pilot_cli.models.package import Package
from nomad_pilot_cli.models.package_item import PackageItem
from nomad_pilot_cli.models.package_item_quick import PackageItemQuick
from nomad_pilot_cli.models.package_items import PackageItems
from nomad_pilot_cli.models.package_items_quick import PackageItemsQuick
from nomad_pilot_cli.models.package_quick import PackageQuick
from nomad_pilot_cli.models.package_required import PackageRequired
from nomad_pilot_cli.models.package_update import PackageUpdate
from nomad_pilot_cli.models.package_update_required import PackageUpdateRequired

