# coding: utf-8

"""
    Nomad Pilot

    This is the API descriptor for the Nomad Pilot API, responsible for shipping and logistics processing. Developed by `Samarkand Global <https://samarkand.global>`_ in partnership with `SF Express <https://www.sf- express.com/cn/sc/>`_, `eSinotrans <http://www.esinotrans.com/haitao.html>`_. Read the documentation online at `Nomad API Suite <https://api.samarkand.io/>`_ and Check out the detailed `changelog <https://gitlab.com/samarkand-nomad/nomad_readme/-/raw/master/history/nomad_pilot.md>`_. - Install for node with ``npm install nomad_pilot_cli`` - Install for python with ``pip install nomad-pilot-cli``  # noqa: E501

    The version of the OpenAPI document: 1.29.1
    Contact: paul@samarkand.global
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import nomad_pilot_cli
from nomad_pilot_cli.models.package_required import PackageRequired  # noqa: E501
from nomad_pilot_cli.rest import ApiException

class TestPackageRequired(unittest.TestCase):
    """PackageRequired unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test PackageRequired
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = nomad_pilot_cli.models.package_required.PackageRequired()  # noqa: E501
        if include_optional :
            return PackageRequired(
                seller_order_ref = '0', 
                express_type = '0', 
                currency = 'RMB', 
                mass_unit = 'Kilogram', 
                length_unit = 'Centimetre', 
                ship_from = null, 
                ship_to = null
            )
        else :
            return PackageRequired(
                seller_order_ref = '0',
                express_type = '0',
                currency = 'RMB',
                mass_unit = 'Kilogram',
                length_unit = 'Centimetre',
        )

    def testPackageRequired(self):
        """Test PackageRequired"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
