# coding: utf-8

"""
    Nomad Pilot

    This is the API descriptor for the Nomad Pilot API, responsible for shipping and logistics processing. Developed by `Samarkand Global <https://samarkand.global>`_ in partnership with `SF Express <https://www.sf- express.com/cn/sc/>`_, `eSinotrans <http://www.esinotrans.com/haitao.html>`_. Read the documentation online at `Nomad API Suite <https://api.samarkand.io/>`_ and Check out the detailed `changelog <https://gitlab.com/samarkand-nomad/nomad_readme/-/raw/master/history/nomad_pilot.md>`_. - Install for node with ``npm install nomad_pilot_cli`` - Install for python with ``pip install nomad-pilot-cli``  # noqa: E501

    The version of the OpenAPI document: 1.29.1
    Contact: paul@samarkand.global
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import nomad_pilot_cli
from nomad_pilot_cli.models.package_items import PackageItems  # noqa: E501
from nomad_pilot_cli.rest import ApiException

class TestPackageItems(unittest.TestCase):
    """PackageItems unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test PackageItems
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = nomad_pilot_cli.models.package_items.PackageItems()  # noqa: E501
        if include_optional :
            return PackageItems(
                items = [
                    nomad_pilot_cli.models.package_item.PackageItem(
                        name = '0', 
                        name_cn = '0', 
                        barcode = '0', 
                        sku_number = 'SMK123', 
                        quantity = 7, 
                        price = 21.3, 
                        brand = '0', 
                        quantity_uom = '50G', 
                        hs_code = '0', 
                        country_of_origin = '0', 
                        goldjet = nomad_pilot_cli.models.goldjet.Goldjet(
                            goods_ptcode = '0', ), 
                        gross_weight = 1.337, 
                        net_weight = 1.337, 
                        customs_unit_code = '142, 007, 瓶, ...', 
                        customs_unit_code_package = '142, 011, 140', 
                        customs_unit_code_weight = '035', 
                        customs_filing_id = '0', 
                        spec = '25mm', 
                        model = 'iPhone XR', 
                        ingredients = '发酵乳杆菌Lc40（CECT5716），麦芽糊精，蔗糖，抗坏血酸钠', )
                    ]
            )
        else :
            return PackageItems(
        )

    def testPackageItems(self):
        """Test PackageItems"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
